aind\_behavior\_curriculum.task.TaskParameters
==============================================

.. currentmodule:: aind_behavior_curriculum.task

.. autoclass:: TaskParameters
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TaskParameters.__init__
      ~TaskParameters.construct
      ~TaskParameters.copy
      ~TaskParameters.dict
      ~TaskParameters.from_orm
      ~TaskParameters.json
      ~TaskParameters.model_construct
      ~TaskParameters.model_copy
      ~TaskParameters.model_dump
      ~TaskParameters.model_dump_json
      ~TaskParameters.model_json_schema
      ~TaskParameters.model_parametrized_name
      ~TaskParameters.model_post_init
      ~TaskParameters.model_rebuild
      ~TaskParameters.model_validate
      ~TaskParameters.model_validate_json
      ~TaskParameters.model_validate_strings
      ~TaskParameters.parse_file
      ~TaskParameters.parse_obj
      ~TaskParameters.parse_raw
      ~TaskParameters.schema
      ~TaskParameters.schema_json
      ~TaskParameters.update_forward_refs
      ~TaskParameters.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TaskParameters.model_computed_fields
      ~TaskParameters.model_config
      ~TaskParameters.model_extra
      ~TaskParameters.model_fields
      ~TaskParameters.model_fields_set
   
   